@@ -104,6 +104,18 @@ head(txi.rsem$counts)
 #  files <- "path/to/alevin/quants_mat.gz"
 #  txi <- tximport(files, type="alevin")
 
+## ---- results="hide", messages=FALSE------------------------------------------
+library(DESeq2)
+
+## -----------------------------------------------------------------------------
+sampleTable <- data.frame(condition=factor(rep(c("A","B"),each=3)))
+rownames(sampleTable) <- colnames(txi$counts)
+
+## -----------------------------------------------------------------------------
+dds <- DESeqDataSetFromTximport(txi, sampleTable, ~ condition)
+# dds is now ready for DESeq()
+# see DESeq2 vignette
+
 ## ---- results="hide", messages=FALSE------------------------------------------
 library(edgeR)
 
@@ -129,8 +141,10 @@ normMat <- log(normMat)
 # Creating a DGEList object for use in edgeR.
 y <- DGEList(cts)
 y <- scaleOffset(y, normMat)
-# filtering
-keep <- filterByExpr(y)
+
+# filtering using the design information
+design <- model.matrix(~ condition, data=sampleTable)
+keep <- filterByExpr(y, design)
 y <- y[keep,]
 # y is now ready for estimate dispersion functions
 # see edgeR User's Guide
@@ -138,18 +152,6 @@ y <- y[keep,]
 ## -----------------------------------------------------------------------------
 cpms <- edgeR::cpm(y, offset=y$offset, log=FALSE)
 
-## ---- results="hide", messages=FALSE------------------------------------------
-library(DESeq2)
-
-## -----------------------------------------------------------------------------
-sampleTable <- data.frame(condition=factor(rep(c("A","B"),each=3)))
-rownames(sampleTable) <- colnames(txi$counts)
-
-## -----------------------------------------------------------------------------
-dds <- DESeqDataSetFromTximport(txi, sampleTable, ~ condition)
-# dds is now ready for DESeq()
-# see DESeq2 vignette
-
 ## -----------------------------------------------------------------------------
 files <- file.path(dir,"salmon", samples$run, "quant.sf.gz")
 names(files) <- paste0("sample",1:6)
@@ -158,11 +160,14 @@ txi <- tximport(files, type="salmon",
                 countsFromAbundance="lengthScaledTPM")
 library(limma)
 y <- DGEList(txi$counts)
-# filtering
-keep <- filterByExpr(y)
-y <- y[keep,]
-y <- calcNormFactors(y)
+
+# filtering using the design information:
 design <- model.matrix(~ condition, data=sampleTable)
+keep <- filterByExpr(y, design)
+y <- y[keep,]
+
+# normalize and run voom transformation
+y <- calcNormFactors(y)
 v <- voom(y, design)
 # v is now ready for lmFit()
 # see limma User's Guide
